{% extends "admin/object_history.html" %}
{% load i18n %}
{% load admin_urls %}

{% block content %}
    <div id="content-main">
        <div class="module">
            {% if action_list %}
                <table id="change-history">
                    <thead>
                    <tr>
                        <th scope="col">ID</th>
                        <th scope="col">Model</th>
                        <th scope="col">Data</th>
                        <th scope="col">Date created</th>
                        <th scope="col">Action</th>
                        <th scope="col">User</th>
                    </tr>
                    </thead>
                    <tbody>
                    {% for action in action_list %}
                        <tr>
                            <td>
                                <a href="/admin/model_log/log/{{ action.id }}/change/">
                                    {{ action.id }}
                                </a>
                            </td>

                            <td>{{ action.model }}</td>
                            <td>{{ action.data }}</td>
                            <td>{{ action.date_created }}</td>
                            <td>{{ action.action_label }}</td>
                            <td>{{ action.user }}</td>
                        </tr>
                    {% endfor %}
                    </tbody>
                </table>
            {% else %}
                <p>{% trans "This object doesn't have a change history." %}</p>
            {% endif %}
        </div>
    </div>
{% endblock %}