# Generated by Django 3.1.7 on 2021-02-23 15:02

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_created', models.DateTimeField(auto_now_add=True, db_index=True, help_text='The date and time this changes was.', verbose_name='Date created')),
                ('object_id', models.IntegerField(help_text='Primary key of the object under version control.')),
                ('object', models.CharField(help_text='Model of the object under version control.', max_length=128)),
                ('data', models.TextField(blank=True, help_text='The data being changed.', null=True)),
                ('action', models.CharField(choices=[('C', 'Created'), ('U', 'Updated'), ('D', 'Deleted')], help_text='created|updated|deleted', max_length=1, verbose_name='Action')),
                ('user', models.ForeignKey(blank=True, help_text='The user who created this changes.', null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('-pk',),
            },
        ),
    ]
