# Generated by Django 3.1.7 on 2021-02-24 14:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('model_log', '0002_auto_20210223_1345'),
    ]

    operations = [
        migrations.AddField(
            model_name='log',
            name='user',
            field=models.TextField(blank=True, help_text='ID of the user who makes the action', null=True),
        ),
    ]
